#! /usr/bin/env bash
# This file contains the complete sequence of commands
# CodeSourcery used to build this version of Sourcery G++.
# 
# For each free or open-source component of Sourcery G++, the
# source code provided includes all of the configuration
# scripts and makefiles for that component, including any and
# all modifications made by CodeSourcery.  From this list of
# commands, you can see every configuration option used by
# CodeSourcery during the build process.
# 
# This file is provided as a guideline for users who wish to
# modify and rebuild a free or open-source component of
# Sourcery G++ from source. For a number of reasons, though,
# you may not be able to successfully run this script directly
# on your system. Certain aspects of the CodeSourcery build
# environment (such as directory names) are included in these
# commands. CodeSourcery uses Canadian cross compilers so you
# may need to modify various configuration options and paths
# if you are building natively. This sequence of commands
# includes those used to build proprietary components of
# Sourcery G++ for which source code is not provided.
# 
# Please note that Sourcery G++ support covers only your use
# of the original, validated binaries provided as part of
# Sourcery G++ -- and specifically does not cover either the
# process of rebuilding a component or the use of any binaries
# you may build.  In addition, if you rebuild any component,
# you must not use the --with-pkgversion and --with-bugurl
# configuration options that embed CodeSourcery trademarks in
# the resulting binary; see the "CodeSourcery Trademarks"
# section in the Sourcery G++ Software License Agreement.
set -e
inform_fd=2 
umask 022
exec < /dev/null

error_handler ()
{
    exit 1
}

check_status() {
    local status="$?"
    if [ "$status" -ne 0 ]; then
	error_handler
    fi
}

check_pipe() {
    local -a status=("${PIPESTATUS[@]}")
    local limit=$1
    local ix
    
    if [ -z "$limit" ] ; then
	limit="${#status[@]}"
    fi
    for ((ix=0; ix != $limit ; ix++)); do
	if [ "${status[$ix]}" != "0" ] ; then
	    error_handler
	fi
    done
}

error () {
    echo "$script: error: $@" >& $inform_fd
    exit 1
}

warning () {
    echo "$script: warning: $@" >& $inform_fd
}

verbose () {
    if $gnu_verbose; then
	echo "$script: $@" >& $inform_fd
    fi
}

copy_dir() {
    mkdir -p "$2"

    (cd "$1" && tar cf - .) | (cd "$2" && tar xf -)
    check_pipe
}

copy_dir_clean() {
    mkdir -p "$2"
    (cd "$1" && tar cf - \
	--exclude=CVS --exclude=.svn --exclude=.pc \
	--exclude="*~" --exclude=".#*" \
	--exclude="*.orig" --exclude="*.rej" \
	.) | (cd "$2" && tar xf -)
    check_pipe
}

update_dir_clean() {
    mkdir -p "$2"


    (cd "$1" && tar cf - \
	--exclude=CVS --exclude=.svn --exclude=.pc \
	--exclude="*~" --exclude=".#*" \
	--exclude="*.orig" --exclude="*.rej" \
	--after-date="$3" \
	. 2> /dev/null) | (cd "$2" && tar xf -)
    check_pipe
}

copy_dir_exclude() {
    local source="$1"
    local dest="$2"
    local excl="$3"
    shift 3
    mkdir -p "$dest"
    (cd "$source" && tar cfX - "$excl" "$@") | (cd "$dest" && tar xf -)
    check_pipe
}

copy_dir_only() {
    local source="$1"
    local dest="$2"
    shift 2
    mkdir -p "$dest"
    (cd "$source" && tar cf - "$@") | (cd "$dest" && tar xf -)
    check_pipe
}

clean_environment() {
    local env_var_list
    local var




    unset BASH_ENV CDPATH POSIXLY_CORRECT TMOUT

    env_var_list=$(export | \
	grep '^declare -x ' | \
	sed -e 's/^declare -x //' -e 's/=.*//')

    for var in $env_var_list; do
	case $var in
	    CSL_SCRIPTDIR|HOME|HOSTNAME|LOGNAME|PWD|SHELL|SHLVL|SSH_*|TERM|USER)


		;;
	    LD_LIBRARY_PATH|PATH| \
		QMTEST_CLASS_PATH| \
		FLEXLM_NO_CKOUT_INSTALL_LIC|LM_APP_DISABLE_CACHE_READ)


		;;
	    MAKEINFO)

		;;
	    *_LICENSE_FILE)












		if [ "" ]; then
		    local license_file_envvar
		    license_file_envvar=

		    if [ "$var" != "$license_file_envvar" ]; then
			export -n "$var" || true
		    fi
		else
		    export -n "$var" || true
		fi
		;;
	    *)

		export -n "$var" || true
		;;
	esac
    done


    export LANG=C
    export LC_ALL=C


    export CVS_RSH=ssh



    export SHELL=$BASH
    export CONFIG_SHELL=$BASH
}

pushenv() {
    pushenv_level=$(($pushenv_level + 1))
    eval pushenv_vars_${pushenv_level}=
}


pushenv_level=0
pushenv_vars_0=



pushenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    eval local pushenv_oldset=\"\${$pushenv_var+set}\"
    local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
    local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
    eval local pushenv_save_set=\"\${$pushenv_savep_var+set}\"
    if [ "$pushenv_save_set" = "set" ]; then
	error "Pushing $pushenv_var more than once at level $pushenv_level"
    fi
    if [ "$pushenv_oldset" = "set" ]; then
	eval $pushenv_save_var=\"\$pushenv_oldval\"
    else
	unset $pushenv_save_var
    fi
    eval $pushenv_savep_var=1
    eval export $pushenv_var=\"\$pushenv_newval\"
    local pushenv_list_var=pushenv_vars_${pushenv_level}
    eval $pushenv_list_var=\"\$$pushenv_list_var \$pushenv_var\"
}

prependenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    pushenvvar "$pushenv_var" "$pushenv_newval$pushenv_oldval"
}

popenv() {
    local pushenv_var=
    eval local pushenv_vars=\"\$pushenv_vars_${pushenv_level}\"
    for pushenv_var in $pushenv_vars; do
	local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
	local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
	eval local pushenv_save_val=\"\$$pushenv_save_var\"
	eval local pushenv_save_set=\"\${$pushenv_save_var+set}\"
	unset $pushenv_save_var
	unset $pushenv_savep_var
	if [ "$pushenv_save_set" = "set" ]; then
	    eval export $pushenv_var=\"\$pushenv_save_val\"
	else
	    unset $pushenv_var
	fi
    done
    unset pushenv_vars_${pushenv_level}
    if [ "$pushenv_level" = "0" ]; then
	error "Popping environment level 0"
    else
	pushenv_level=$(($pushenv_level - 1))
    fi
}

prepend_path() {
    if $(eval "test -n \"\$$1\""); then
	prependenvvar "$1" "$2:"
    else
	prependenvvar "$1" "$2"
    fi
}
pushenvvar CSL_SCRIPTDIR /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/scripts-trunk
pushenvvar PATH /usr/local/tools/gcc-4.3.3/bin
pushenvvar LD_LIBRARY_PATH /usr/local/tools/gcc-4.3.3/lib64:/usr/local/tools/gcc-4.3.3/lib:/usr/local/tools/gcc-4.3.3/i686-pc-linux-gnu/lib
pushenvvar QMTEST_CLASS_PATH QMTEST_CLASS_PATH
pushenvvar MAKEINFO 'makeinfo --css-ref=../cs.css'
clean_environment
# task [001/107] /init/dirs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite
mkdir -p /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite
mkdir -p /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite
mkdir -p /scratch/maxim/arm-lite/logs-4.3-arm-none-symbianelf-lite/data
mkdir -p /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/html
mkdir -p /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/pdf
popenv

# task [002/107] /init/cleanup
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite/arm-2009q1-162-arm-none-symbianelf.src.tar.bz2 /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite/arm-2009q1-162-arm-none-symbianelf.backup.tar.bz2
popenv

# task [003/107] /init/source_package/binutils
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/binutils-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/binutils-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' binutils-stable
popd
popenv

# task [004/107] /init/source_package/gcc
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/gcc-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/gcc-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' gcc-4.3
popd
popenv

# task [005/107] /init/source_package/zlib
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/zlib-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/zlib-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' zlib-1.2.3
popd
popenv

# task [006/107] /init/source_package/gmp
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/gmp-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/gmp-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' gmp-stable
popd
popenv

# task [007/107] /init/source_package/mpfr
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/mpfr-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/mpfr-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' mpfr-stable
popd
popenv

# task [008/107] /init/source_package/getting_started
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/getting_started-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/getting_started-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' getting-started-stable
popd
popenv

# task [009/107] /init/source_package/installanywhere
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/installanywhere-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/installanywhere-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' installanywhere-stable
popd
popenv

# task [010/107] /init/source_package/csl_tests
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/csl_tests-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/csl_tests-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' csl-tests-trunk
popd
popenv

# task [011/107] /init/source_package/dejagnu_boards
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/dejagnu_boards-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/dejagnu_boards-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' dejagnu-boards-trunk
popd
popenv

# task [012/107] /init/source_package/scripts
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/scripts-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/scripts-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' scripts-trunk
popd
popenv

# task [013/107] /init/source_package/xfails
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/xfails-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/xfails-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' xfails-trunk
popd
popenv

# task [014/107] /init/source_package/portal
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/portal-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/portal-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' portal-trunk
popd
popenv

# task [015/107] /init/source_package/libiconv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/libiconv-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/libiconv-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' libiconv-1.11
popd
popenv

# task [016/107] /init/source_package/csl_docbook
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/csl_docbook-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup/csl_docbook-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' csl-docbook-trunk
popd
popenv

# task [017/107] /init/source_package/make
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/make-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/make-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' make-3.81
popd
popenv

# task [018/107] /init/source_package/coreutils
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/coreutils-2009q1-162.tar.bz2
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf
pushd /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite
tar cf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf/coreutils-2009q1-162.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' coreutils-5.94
popd
popenv

# task [019/107] /i686-pc-linux-gnu/host_cleanup
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
popenv

# task [020/107] /i686-pc-linux-gnu/zlib_first/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-first-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
copy_dir_clean /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/zlib-1.2.3 /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-first-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
chmod -R u+w /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-first-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
popenv

# task [021/107] /i686-pc-linux-gnu/zlib_first/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-first-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
pushenv
pushenvvar CC 'i686-pc-linux-gnu-gcc '
pushenvvar AR 'i686-pc-linux-gnu-ar rc'
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
./configure --prefix=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr
popenv
popd
popenv

# task [022/107] /i686-pc-linux-gnu/zlib_first/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-first-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv

# task [023/107] /i686-pc-linux-gnu/zlib_first/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-first-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make install
popd
popenv

# task [024/107] /i686-pc-linux-gnu/gmp/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gmp-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gmp-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gmp-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/gmp-stable/configure --build=i686-pc-linux-gnu --target=i686-pc-linux-gnu --prefix=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr --disable-shared --host=i686-pc-linux-gnu --disable-nls
popd
popenv
popenv
popenv

# task [025/107] /i686-pc-linux-gnu/gmp/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gmp-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [026/107] /i686-pc-linux-gnu/gmp/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gmp-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make install
popd
popenv
popenv
popenv

# task [027/107] /i686-pc-linux-gnu/gmp/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gmp-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make check
popd
popenv
popenv
popenv

# task [028/107] /i686-pc-linux-gnu/mpfr/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/mpfr-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/mpfr-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/mpfr-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/mpfr-stable/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr --disable-shared --host=i686-pc-linux-gnu --disable-nls --with-gmp=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr
popd
popenv
popenv
popenv

# task [029/107] /i686-pc-linux-gnu/mpfr/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/mpfr-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [030/107] /i686-pc-linux-gnu/mpfr/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/mpfr-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make install
popd
popenv
popenv
popenv

# task [031/107] /i686-pc-linux-gnu/mpfr/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/mpfr-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make check
popd
popenv
popenv
popenv

# task [032/107] /i686-pc-linux-gnu/toolchain/binutils/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
pushenvvar LDFLAGS -L/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-src-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
copy_dir_clean /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/binutils-stable /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-src-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
chmod -R u+w /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-src-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
touch /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-src-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/.gnu-stamp
popenv
popenv
popenv

# task [033/107] /i686-pc-linux-gnu/toolchain/binutils/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
pushenvvar LDFLAGS -L/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-src-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-pc-linux-gnu '--with-pkgversion=Sourcery G++ Lite 2009q1-162' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --enable-poison-system-directories
popd
popenv
popenv
popenv

# task [034/107] /i686-pc-linux-gnu/toolchain/binutils/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
pushenvvar LDFLAGS -L/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [035/107] /i686-pc-linux-gnu/toolchain/binutils/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
pushenvvar LDFLAGS -L/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make install prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite exec_prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite libdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/lib htmldir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/man datadir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share
popd
popenv
popenv
popenv

# task [036/107] /i686-pc-linux-gnu/toolchain/binutils/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
pushenvvar LDFLAGS -L/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
pushd /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite
rm ./lib/libiberty.a
rmdir ./lib
popd
copy_dir_clean /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/binutils-stable/include /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
chmod -R u+w /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/libiberty/libiberty.a /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/bfd/.libs/libbfd.a /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/bfd/bfd.h /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
cp /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/binutils-stable/bfd/elf-bfd.h /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
cp /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/opcodes/.libs/libopcodes.a /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
popenv
popenv
popenv

# task [037/107] /i686-pc-linux-gnu/toolchain/gcc_final/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gcc-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gcc-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gcc-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/gcc-4.3/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --enable-threads --disable-libmudflap --disable-libssp --disable-libstdcxx-pch --with-gnu-as --with-gnu-ld --enable-languages=c,c++ --enable-shared '--with-pkgversion=Sourcery G++ Lite 2009q1-162' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --prefix=/opt/codesourcery --with-gmp=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr --with-mpfr=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr --disable-libgomp --enable-poison-system-directories --with-build-time-tools=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/bin --with-build-time-tools=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/bin
popd
popenv
popenv

# task [038/107] /i686-pc-linux-gnu/toolchain/gcc_final/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gcc-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv

# task [039/107] /i686-pc-linux-gnu/toolchain/gcc_final/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gcc-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite exec_prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite libdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/lib htmldir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/man install
popd
popenv
popenv

# task [040/107] /i686-pc-linux-gnu/toolchain/gcc_final/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushd /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite
rm bin/arm-none-symbianelf-gccbug
rm ./lib/libiberty.a
rmdir include
popd
popenv
popenv

# task [041/107] /i686-pc-linux-gnu/toolchain/zlib/0/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
copy_dir_clean /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/zlib-1.2.3 /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
chmod -R u+w /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
popenv

# task [042/107] /i686-pc-linux-gnu/toolchain/zlib/0/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
pushenv
pushenvvar CC 'i686-pc-linux-gnu-gcc '
pushenvvar AR 'i686-pc-linux-gnu-ar rc'
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
./configure --prefix=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/usr
popenv
popd
popenv

# task [043/107] /i686-pc-linux-gnu/toolchain/zlib/0/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv

# task [044/107] /i686-pc-linux-gnu/toolchain/zlib/0/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make install
popd
popenv

# task [045/107] /i686-pc-linux-gnu/getting_started/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-src-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
copy_dir_clean /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/getting-started-stable /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-src-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
chmod -R u+w /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-src-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
touch /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-src-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/.gnu-stamp
cat > /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-src-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/4.3-arm-none-symbianelf-lite-libs.xml <<'EOF0'
<!DOCTYPE getting-started SYSTEM "getting-started.dtd">
<!-- automatically generated, do not edit -->
<section id="sec-multilibs">
  <title>Library Configurations</title>
  <xi:include href="library-intro.xml" xpointer="xpointer(*/*)"/>
  <section>
    <title>Included Libraries</title>
    <para>
      The following library configurations are available in
      &csl_prod; for &csl_target_name;.
    </para>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">ARMv5 - Little-Endian, Soft-Float</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry>default</entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">ARMv5 - Little-Endian, VFP</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-mfloat-abi=softfp</option></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
    </section>
  <xi:include href="library-selection.xml"/>
</section>
EOF0
cat > /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-src-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/4.3-arm-none-symbianelf-lite.dtd <<'EOF0'
<!-- automatically generated, do not edit -->
<!ENTITY csl_multilib_sec "<xi:include href='/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-src-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/4.3-arm-none-symbianelf-lite-libs.xml'/>">
<!ENTITY csl_subpackage_sec "">
EOF0
popenv
popenv
popenv

# task [046/107] /i686-pc-linux-gnu/getting_started/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-src-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-pc-linux-gnu '--with-component-licenses= binutils=gpl3.0 gcc=gpl3.0 make=gpl2.0 coreutils=gpl2.0' --disable-nls --with-release-config=4.3-arm-none-symbianelf-lite '--with-components=binutils gcc zlib gmp mpfr getting_started installanywhere branding contents comparison csl_tests dejagnu_boards scripts xfails portal libiconv csl_docbook make coreutils no-mingw no-w32api no-alf no-argp no-arm_stub no-board_support no-ccs no-cctools no-cfpe_stub no-cloog no-cml no-com_codesourcery_util no-cs3 no-csldoc no-cxxabi no-cygwin_wrapper no-dhrystone no-dinkum no-dtc no-eclipse no-eclipse_cdt no-eclipse_plugin no-eclipse_step_through no-eembc no-eglibc no-elf2flt no-elfutils no-expat no-gdb no-gdil no-glibc no-glibc_linuxthreads no-glibc_localedef no-glibc_ports no-harness_test no-libcsftdi no-libelf no-libftdi no-libpng no-libsdl no-libunwind no-libusb no-libusb_win32 no-license no-linux no-mips_toolchain_manual no-mklibs no-mpatrol no-ncurses no-newlib no-null no-ocdremote no-omf2elf no-openposix no-osprey no-ph no-ph_old no-plex_skel no-ppl no-prelink no-python no-python_win32 no-qemu no-qmtest_ph no-redboot no-rpm no-sde no-sdemdi no-sgxx_demos no-simdmath no-spec2000 no-spec2000_configs no-srpm no-svp_docs no-sysroot_utils no-trace_processor no-uclibc no-uclibc_configs no-vpp_binary no-vpp_fftw no-vpp_source no-windows_script_wrapper' '--with-features=armfloat tarball' '--with-hosts=i686-pc-linux-gnu i686-mingw32' '--with-host_os-name=IA32 GNU/Linux' --with-target-arch-name=ARM --with-target-os-name=SymbianOS --with-intermediate-dir=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-2009q1-162-arm-none-symbianelf --with-csl-docbook=/scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/csl-docbook-trunk --with-version-string=2009q1-162 '--with-pkgversion=Sourcery G++ Lite 2009q1-162' '--with-brand=Sourcery G++ Lite' '--with-xml-catalog-files=/usr/local/tools/gcc-4.3.3/share/sgml/docbook/docbook-xsl/catalog.xml /etc/xml/catalog' --with-license=lite
popd
popenv
popenv
popenv

# task [047/107] /i686-pc-linux-gnu/getting_started/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [048/107] /i686-pc-linux-gnu/getting_started/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushenv
pushenv
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu
make install prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite exec_prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite libdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/lib htmldir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/man datadir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share docdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf
popd
popenv
popenv
popenv

# task [049/107] /i686-pc-linux-gnu/csl_docbook
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
cp /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/csl-docbook-trunk/css/cs.css /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/share/doc/arm-arm-none-symbianelf/html
popenv

# task [050/107] /i686-pc-linux-gnu/finalize_libc_installation
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
popenv

# task [051/107] /i686-pc-linux-gnu/pretidy_installation
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushd /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite
popd
popenv

# task [052/107] /i686-pc-linux-gnu/remove_libtool_archives
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
find /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite -name '*.la' -exec rm '{}' ';'
popenv

# task [053/107] /i686-pc-linux-gnu/remove_copied_libs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
popenv

# task [054/107] /i686-pc-linux-gnu/remove_fixed_headers
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
pushd /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/lib/gcc/arm-none-symbianelf/4.3.3/include-fixed
popd
popenv

# task [055/107] /i686-pc-linux-gnu/strip_host_objects
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-addr2line
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-ar
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-as
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-c++
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-c++filt
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-cpp
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-g++
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-gcc
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-gcc-4.3.3
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-gcov
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-gprof
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-ld
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-nm
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-objcopy
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-objdump
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-ranlib
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-readelf
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-size
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-strings
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin/arm-none-symbianelf-strip
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/bin/ar
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/bin/as
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/bin/c++
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/bin/g++
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/bin/gcc
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/bin/ld
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/bin/nm
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/bin/objcopy
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/bin/objdump
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/bin/ranlib
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/bin/strip
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/libexec/gcc/arm-none-symbianelf/4.3.3/cc1
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/libexec/gcc/arm-none-symbianelf/4.3.3/collect2
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/libexec/gcc/arm-none-symbianelf/4.3.3/install-tools/fixincl
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/libexec/gcc/arm-none-symbianelf/4.3.3/cc1plus
popenv

# task [056/107] /i686-pc-linux-gnu/strip_target_objects
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
arm-none-symbianelf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/lib/libsupc++.a || true
arm-none-symbianelf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/arm-none-symbianelf/lib/mfloat-abi=softfp/libsupc++.a || true
arm-none-symbianelf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/lib/gcc/arm-none-symbianelf/4.3.3/libgcov.a || true
arm-none-symbianelf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/lib/gcc/arm-none-symbianelf/4.3.3/softfp/libgcov.a || true
arm-none-symbianelf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/lib/gcc/arm-none-symbianelf/4.3.3/softfp/libgcc.a || true
arm-none-symbianelf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/lib/gcc/arm-none-symbianelf/4.3.3/libgcc.a || true
popenv

# task [057/107] /i686-pc-linux-gnu/package_tbz2
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
rm -f /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite/arm-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite
rm -f arm-2009q1
ln -s /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite arm-2009q1
tar cjf /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite/arm-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --owner=0 --group=0 --exclude=host-i686-pc-linux-gnu --exclude=host-i686-mingw32 arm-2009q1/arm-none-symbianelf arm-2009q1/bin arm-2009q1/lib arm-2009q1/libexec arm-2009q1/share
rm -f arm-2009q1
popd
popenv

# task [058/107] /i686-pc-linux-gnu/package_installanywhere
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/bin
/scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/scripts-trunk/gnu-installanywhere -i /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite -l /scratch/maxim/arm-lite/logs-4.3-arm-none-symbianelf-lite -o /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite -p /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite -s /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite -T /scratch/maxim/arm-lite/testlogs-4.3-arm-none-symbianelf-lite -h i686-pc-linux-gnu -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-2009q1-162-arm-none-symbianelf/license.html 4.3-arm-none-symbianelf-lite
popenv

# task [059/107] /i686-mingw32/host_cleanup
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
popenv

# task [060/107] /i686-mingw32/host_unpack
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32
mkdir /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32
ln -s . arm-2009q1
tar xf /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite/arm-2009q1-162-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --bzip2
rm arm-2009q1
popd
popenv

# task [061/107] /i686-mingw32/libiconv/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/libiconv-2009q1-162-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/libiconv-2009q1-162-arm-none-symbianelf-i686-mingw32
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/libiconv-2009q1-162-arm-none-symbianelf-i686-mingw32
/scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/libiconv-1.11/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr --disable-shared --host=i686-mingw32 --disable-nls
popd
popenv
popenv
popenv

# task [062/107] /i686-mingw32/libiconv/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/libiconv-2009q1-162-arm-none-symbianelf-i686-mingw32
make -j1
popd
popenv
popenv
popenv

# task [063/107] /i686-mingw32/libiconv/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/libiconv-2009q1-162-arm-none-symbianelf-i686-mingw32
make install
popd
popenv
popenv
popenv

# task [064/107] /i686-mingw32/make/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/make-src-2009q1-162-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/make-3.81 /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/make-src-2009q1-162-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/make-src-2009q1-162-arm-none-symbianelf-i686-mingw32
touch /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/make-src-2009q1-162-arm-none-symbianelf-i686-mingw32/.gnu-stamp
popenv
popenv
popenv

# task [065/107] /i686-mingw32/make/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/make-2009q1-162-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/make-2009q1-162-arm-none-symbianelf-i686-mingw32
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/make-2009q1-162-arm-none-symbianelf-i686-mingw32
/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/make-src-2009q1-162-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-mingw32 '--with-pkgversion=Sourcery G++ Lite 2009q1-162' --disable-nls --program-prefix=cs-
popd
popenv
popenv
popenv

# task [066/107] /i686-mingw32/make/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/make-2009q1-162-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [067/107] /i686-mingw32/make/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/make-2009q1-162-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32 exec_prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32 libdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/lib htmldir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/man datadir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share
popd
popenv
popenv
popenv

# task [068/107] /i686-mingw32/coreutils/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/coreutils-src-2009q1-162-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/coreutils-5.94 /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/coreutils-src-2009q1-162-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/coreutils-src-2009q1-162-arm-none-symbianelf-i686-mingw32
touch /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/coreutils-src-2009q1-162-arm-none-symbianelf-i686-mingw32/.gnu-stamp
popenv
popenv
popenv

# task [069/107] /i686-mingw32/coreutils/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/coreutils-2009q1-162-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/coreutils-2009q1-162-arm-none-symbianelf-i686-mingw32
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/coreutils-2009q1-162-arm-none-symbianelf-i686-mingw32
/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/coreutils-src-2009q1-162-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-mingw32 '--with-pkgversion=Sourcery G++ Lite 2009q1-162' --disable-nls --program-prefix=cs-
popd
popenv
popenv
popenv

# task [070/107] /i686-mingw32/coreutils/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/coreutils-2009q1-162-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [071/107] /i686-mingw32/coreutils/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/coreutils-2009q1-162-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32 exec_prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32 libdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/lib htmldir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/man datadir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share
popd
popenv
popenv
popenv

# task [072/107] /i686-mingw32/zlib_first/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-first-2009q1-162-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/zlib-1.2.3 /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-first-2009q1-162-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-first-2009q1-162-arm-none-symbianelf-i686-mingw32
popenv

# task [073/107] /i686-mingw32/zlib_first/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-first-2009q1-162-arm-none-symbianelf-i686-mingw32
pushenv
pushenvvar CC 'i686-mingw32-gcc '
pushenvvar AR 'i686-mingw32-ar rc'
pushenvvar RANLIB i686-mingw32-ranlib
./configure --prefix=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr
popenv
popd
popenv

# task [074/107] /i686-mingw32/zlib_first/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-first-2009q1-162-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv

# task [075/107] /i686-mingw32/zlib_first/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-first-2009q1-162-arm-none-symbianelf-i686-mingw32
make install
popd
popenv

# task [076/107] /i686-mingw32/gmp/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gmp-2009q1-162-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gmp-2009q1-162-arm-none-symbianelf-i686-mingw32
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gmp-2009q1-162-arm-none-symbianelf-i686-mingw32
/scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/gmp-stable/configure --build=i686-pc-linux-gnu --target=i686-mingw32 --prefix=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr --disable-shared --host=i686-mingw32 --disable-nls
popd
popenv
popenv
popenv

# task [077/107] /i686-mingw32/gmp/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gmp-2009q1-162-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [078/107] /i686-mingw32/gmp/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gmp-2009q1-162-arm-none-symbianelf-i686-mingw32
make install
popd
popenv
popenv
popenv

# task [079/107] /i686-mingw32/gmp/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
popenv
popenv
popenv

# task [080/107] /i686-mingw32/mpfr/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/mpfr-2009q1-162-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/mpfr-2009q1-162-arm-none-symbianelf-i686-mingw32
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/mpfr-2009q1-162-arm-none-symbianelf-i686-mingw32
/scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/mpfr-stable/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr --disable-shared --host=i686-mingw32 --disable-nls --with-gmp=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr
popd
popenv
popenv
popenv

# task [081/107] /i686-mingw32/mpfr/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/mpfr-2009q1-162-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [082/107] /i686-mingw32/mpfr/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/mpfr-2009q1-162-arm-none-symbianelf-i686-mingw32
make install
popd
popenv
popenv
popenv

# task [083/107] /i686-mingw32/mpfr/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
popenv
popenv
popenv

# task [084/107] /i686-mingw32/toolchain/binutils/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/include
pushenvvar LDFLAGS -L/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/lib
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-src-2009q1-162-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/binutils-stable /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-src-2009q1-162-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-src-2009q1-162-arm-none-symbianelf-i686-mingw32
touch /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-src-2009q1-162-arm-none-symbianelf-i686-mingw32/.gnu-stamp
popenv
popenv
popenv

# task [085/107] /i686-mingw32/toolchain/binutils/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/include
pushenvvar LDFLAGS -L/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/lib
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-mingw32
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-mingw32
/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-src-2009q1-162-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-mingw32 '--with-pkgversion=Sourcery G++ Lite 2009q1-162' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --enable-poison-system-directories
popd
popenv
popenv
popenv

# task [086/107] /i686-mingw32/toolchain/binutils/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/include
pushenvvar LDFLAGS -L/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/lib
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [087/107] /i686-mingw32/toolchain/binutils/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/include
pushenvvar LDFLAGS -L/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/lib
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32 exec_prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32 libdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/lib htmldir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/man datadir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share
popd
popenv
popenv
popenv

# task [088/107] /i686-mingw32/toolchain/binutils/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/include
pushenvvar LDFLAGS -L/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/lib
pushd /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32
rm lib/charset.alias
rm ./lib/libiberty.a
rmdir ./lib
popd
copy_dir_clean /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/binutils-stable/include /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/include
chmod -R u+w /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/include
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-mingw32/libiberty/libiberty.a /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-mingw32/bfd/.libs/libbfd.a /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-mingw32/bfd/bfd.h /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/include
cp /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/binutils-stable/bfd/elf-bfd.h /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/include
cp /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/binutils-2009q1-162-arm-none-symbianelf-i686-mingw32/opcodes/.libs/libopcodes.a /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-binutils-2009q1-162-arm-none-symbianelf-i686-mingw32/usr/lib
popenv
popenv
popenv

# task [089/107] /i686-mingw32/toolchain/copy_libs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
copy_dir /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/share/doc/arm-arm-none-symbianelf/html /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html
copy_dir /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf
copy_dir /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/share/doc/arm-arm-none-symbianelf/info /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info
copy_dir /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/share/doc/arm-arm-none-symbianelf/man /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/man
cp /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/share/doc/arm-arm-none-symbianelf/LICENSE.txt /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf
popenv

# task [090/107] /i686-mingw32/toolchain/gcc_final/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushenvvar CC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar GCC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar CXX_FOR_TARGET arm-none-symbianelf-g++
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gcc-2009q1-162-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gcc-2009q1-162-arm-none-symbianelf-i686-mingw32
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gcc-2009q1-162-arm-none-symbianelf-i686-mingw32
/scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/gcc-4.3/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --enable-threads --disable-libmudflap --disable-libssp --disable-libstdcxx-pch --with-gnu-as --with-gnu-ld --enable-languages=c,c++ --enable-shared '--with-pkgversion=Sourcery G++ Lite 2009q1-162' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --prefix=/opt/codesourcery --with-libiconv-prefix=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr --with-gmp=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr --with-mpfr=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr --disable-libgomp --enable-poison-system-directories --with-build-time-tools=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/bin --with-build-time-tools=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/bin
popd
popenv
popenv

# task [091/107] /i686-mingw32/toolchain/gcc_final/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushenvvar CC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar GCC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar CXX_FOR_TARGET arm-none-symbianelf-g++
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gcc-2009q1-162-arm-none-symbianelf-i686-mingw32
make -j4 all-gcc
popd
popenv
popenv

# task [092/107] /i686-mingw32/toolchain/gcc_final/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushenvvar CC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar GCC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar CXX_FOR_TARGET arm-none-symbianelf-g++
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gcc-2009q1-162-arm-none-symbianelf-i686-mingw32
make prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32 exec_prefix=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32 libdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/lib htmldir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/man install-gcc
popd
popenv
popenv

# task [093/107] /i686-mingw32/toolchain/gcc_final/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushenvvar CC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar GCC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar CXX_FOR_TARGET arm-none-symbianelf-g++
pushd /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32
rm bin/arm-none-symbianelf-gccbug
rmdir include
popd
copy_dir /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/lib/gcc/arm-none-symbianelf /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/lib/gcc/arm-none-symbianelf
copy_dir /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/lib /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/arm-none-symbianelf/lib
copy_dir /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/include/c++ /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/arm-none-symbianelf/include/c++
popenv
popenv

# task [094/107] /i686-mingw32/toolchain/zlib/0/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
rm -rf /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-2009q1-162-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/zlib-1.2.3 /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-2009q1-162-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-2009q1-162-arm-none-symbianelf-i686-mingw32
popenv

# task [095/107] /i686-mingw32/toolchain/zlib/0/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-2009q1-162-arm-none-symbianelf-i686-mingw32
pushenv
pushenvvar CC 'i686-mingw32-gcc '
pushenvvar AR 'i686-mingw32-ar rc'
pushenvvar RANLIB i686-mingw32-ranlib
./configure --prefix=/scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/host-libs-2009q1-162-arm-none-symbianelf-i686-mingw32/usr
popenv
popd
popenv

# task [096/107] /i686-mingw32/toolchain/zlib/0/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-2009q1-162-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv

# task [097/107] /i686-mingw32/toolchain/zlib/0/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/zlib-2009q1-162-arm-none-symbianelf-i686-mingw32
make install
popd
popenv

# task [098/107] /i686-mingw32/pretidy_installation
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32
popd
popenv

# task [099/107] /i686-mingw32/remove_libtool_archives
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
find /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32 -name '*.la' -exec rm '{}' ';'
popenv

# task [100/107] /i686-mingw32/remove_copied_libs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
popenv

# task [101/107] /i686-mingw32/remove_fixed_headers
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/lib/gcc/arm-none-symbianelf/4.3.3/include-fixed
popd
popenv

# task [102/107] /i686-mingw32/strip_host_objects
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-addr2line.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-ar.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-as.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-c++.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-c++filt.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-cpp.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-g++.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-gcc-4.3.3.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-gcc.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-gcov.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-gprof.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-ld.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-nm.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-objcopy.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-objdump.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-ranlib.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-readelf.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-size.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-strings.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/arm-none-symbianelf-strip.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/cs-make.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/bin/cs-rm.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/arm-none-symbianelf/bin/ar.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/arm-none-symbianelf/bin/as.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/arm-none-symbianelf/bin/c++.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/arm-none-symbianelf/bin/g++.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/arm-none-symbianelf/bin/gcc.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/arm-none-symbianelf/bin/ld.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/arm-none-symbianelf/bin/nm.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/arm-none-symbianelf/bin/objcopy.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/arm-none-symbianelf/bin/objdump.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/arm-none-symbianelf/bin/ranlib.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/arm-none-symbianelf/bin/strip.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.3.3/cc1.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.3.3/collect2.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.3.3/install-tools/fixincl.exe
i686-mingw32-strip /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.3.3/cc1plus.exe
popenv

# task [103/107] /i686-mingw32/package_tbz2
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
rm -f /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite/arm-2009q1-162-arm-none-symbianelf-i686-mingw32.tar.bz2
pushd /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32
popd
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite
rm -f arm-2009q1
ln -s /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32 arm-2009q1
tar cjf /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite/arm-2009q1-162-arm-none-symbianelf-i686-mingw32.tar.bz2 --owner=0 --group=0 --exclude=host-i686-pc-linux-gnu --exclude=host-i686-mingw32 arm-2009q1/arm-none-symbianelf arm-2009q1/bin arm-2009q1/lib arm-2009q1/libexec arm-2009q1/share
rm -f arm-2009q1
popd
popenv

# task [104/107] /i686-mingw32/package_installanywhere
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/tools-i686-pc-linux-gnu-2009q1-162-arm-none-symbianelf-i686-mingw32/bin
/scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/scripts-trunk/gnu-installanywhere -i /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite/host-i686-mingw32 -l /scratch/maxim/arm-lite/logs-4.3-arm-none-symbianelf-lite -o /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite -p /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite -s /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite -T /scratch/maxim/arm-lite/testlogs-4.3-arm-none-symbianelf-lite -h i686-mingw32 -f /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/getting_started-2009q1-162-arm-none-symbianelf/license.html 4.3-arm-none-symbianelf-lite
popenv

# task [105/107] /fini/build_summary
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
cat > /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gnu-2009q1-162-arm-none-symbianelf.txt <<'EOF0'
Version Information
===================

Version:           2009q1-162
Host spec(s):      i686-pc-linux-gnu i686-mingw32
Target:            arm-none-symbianelf

Build Information
=================

Build date:             20090415
Build machine:          verona
Build operating system: 4.0
Build uname:            Linux verona 2.6.20-16-generic #2 SMP Tue Feb 12 02:11:24 UTC 2008 x86_64 GNU/Linux
Build user:             maxim

EOF0
popenv

# task [106/107] /fini/backups_package
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf.backup
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf
tar cjf /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite/arm-2009q1-162-arm-none-symbianelf.backup.tar.bz2 --owner=0 --group=0 arm-2009q1-162-arm-none-symbianelf.backup
popd
popenv

# task [107/107] /fini/sources_package
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf
cp /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/gnu-2009q1-162-arm-none-symbianelf.txt /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf
cp /scratch/maxim/arm-lite/logs-4.3-arm-none-symbianelf-lite/arm-2009q1-162-arm-none-symbianelf.sh /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf/arm-2009q1-162-arm-none-symbianelf
pushd /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/pkg-2009q1-162-arm-none-symbianelf
tar cjf /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite/arm-2009q1-162-arm-none-symbianelf.src.tar.bz2 --owner=0 --group=0 arm-2009q1-162-arm-none-symbianelf
popd
/scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/scripts-trunk/gnu-test -i /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite -l /scratch/maxim/arm-lite/logs-4.3-arm-none-symbianelf-lite -o /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite -p /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite -s /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite -T /scratch/maxim/arm-lite/testlogs-4.3-arm-none-symbianelf-lite -T /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/testlogs-2009q1-162-arm-none-symbianelf 4.3-arm-none-symbianelf-lite
copy_dir /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/testlogs-2009q1-162-arm-none-symbianelf /scratch/maxim/arm-lite/testlogs-4.3-arm-none-symbianelf-lite
/scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite/scripts-trunk/gnu-test-package -i /scratch/maxim/arm-lite/install-4.3-arm-none-symbianelf-lite -l /scratch/maxim/arm-lite/logs-4.3-arm-none-symbianelf-lite -o /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite -p /scratch/maxim/arm-lite/pkg-4.3-arm-none-symbianelf-lite -s /scratch/maxim/arm-lite/src-4.3-arm-none-symbianelf-lite -T /scratch/maxim/arm-lite/testlogs-4.3-arm-none-symbianelf-lite -T /scratch/maxim/arm-lite/obj-4.3-arm-none-symbianelf-lite/testlogs-2009q1-162-arm-none-symbianelf 4.3-arm-none-symbianelf-lite
